==> beast-privilege-api-2.6.4-GS-20230109.064208-20-sources.jar: com/thebeastshop/privilege/vo/StoreRentConfigDetailVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class StoreRentConfigDetailVO implements Serializable {
    private Integer id;
    private Integer rentConfigId;
    private String feeSubject;

    private Date startDate;
    private Date endDate;
    private BigDecimal amountMoney;
    private Integer payObject;
    private Integer computeMode;
    private BigDecimal commissionPercentage;
    private BigDecimal rentRate;
    private String channelCode;
    private Integer contractSubjectId;
    private String channelName;
    private String feeSubjectText;
    private String payObjectText;
    private String computeModeText;
    private String contractSubjectName;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getRentConfigId() {
        return rentConfigId;
    }

    public void setRentConfigId(Integer rentConfigId) {
        this.rentConfigId = rentConfigId;
    }

    public String getFeeSubject() {
        return feeSubject;
    }

    public void setFeeSubject(String feeSubject) {
        this.feeSubject = feeSubject;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public BigDecimal getAmountMoney() {
        return amountMoney;
    }

    public void setAmountMoney(BigDecimal amountMoney) {
        this.amountMoney = amountMoney;
    }

    public Integer getPayObject() {
        return payObject;
    }

    public void setPayObject(Integer payObject) {
        this.payObject = payObject;
    }

    public Integer getComputeMode() {
        return computeMode;
    }

    public void setComputeMode(Integer computeMode) {
        this.computeMode = computeMode;
    }

    public BigDecimal getCommissionPercentage() {
        return commissionPercentage;
    }

    public void setCommissionPercentage(BigDecimal commissionPercentage) {
        this.commissionPercentage = commissionPercentage;
    }

    public BigDecimal getRentRate() {
        return rentRate;
    }

    public void setRentRate(BigDecimal rentRate) {
        this.rentRate = rentRate;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getContractSubjectId() {
        return contractSubjectId;
    }

    public void setContractSubjectId(Integer contractSubjectId) {
        this.contractSubjectId = contractSubjectId;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getFeeSubjectText() {
        return feeSubjectText;
    }

    public void setFeeSubjectText(String feeSubjectText) {
        this.feeSubjectText = feeSubjectText;
    }

    public String getPayObjectText() {
        return payObjectText;
    }

    public void setPayObjectText(String payObjectText) {
        this.payObjectText = payObjectText;
    }
    public String getComputeModeText() {
        return computeModeText;
    }

    public void setComputeModeText(String computeModeText) {
        this.computeModeText = computeModeText;
    }

    public String getContractSubjectName() {
        return contractSubjectName;
    }

    public void setContractSubjectName(String contractSubjectName) {
        this.contractSubjectName = contractSubjectName;
    }

}

==> beast-privilege-api-3.0.11-GS-20250828.055119-1-sources.jar: com/thebeastshop/privilege/vo/StoreRentConfigDetailVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class StoreRentConfigDetailVO implements Serializable {
    private Integer id;
    private Integer rentConfigId;
    private String feeSubject;

    private Date startDate;
    private Date endDate;
    private BigDecimal amountMoney;
    private Integer payObject;
    private Integer computeMode;
    private BigDecimal commissionPercentage;
    private BigDecimal rentRate;
    private String channelCode;
    private Integer contractSubjectId;
    private String channelName;
    private String feeSubjectText;
    private String payObjectText;
    private String computeModeText;
    private String contractSubjectName;

    private BigDecimal noTaxAmountMoney;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getRentConfigId() {
        return rentConfigId;
    }

    public void setRentConfigId(Integer rentConfigId) {
        this.rentConfigId = rentConfigId;
    }

    public String getFeeSubject() {
        return feeSubject;
    }

    public void setFeeSubject(String feeSubject) {
        this.feeSubject = feeSubject;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public BigDecimal getAmountMoney() {
        return amountMoney;
    }

    public void setAmountMoney(BigDecimal amountMoney) {
        this.amountMoney = amountMoney;
    }

    public Integer getPayObject() {
        return payObject;
    }

    public void setPayObject(Integer payObject) {
        this.payObject = payObject;
    }

    public Integer getComputeMode() {
        return computeMode;
    }

    public void setComputeMode(Integer computeMode) {
        this.computeMode = computeMode;
    }

    public BigDecimal getCommissionPercentage() {
        return commissionPercentage;
    }

    public void setCommissionPercentage(BigDecimal commissionPercentage) {
        this.commissionPercentage = commissionPercentage;
    }

    public BigDecimal getRentRate() {
        return rentRate;
    }

    public void setRentRate(BigDecimal rentRate) {
        this.rentRate = rentRate;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getContractSubjectId() {
        return contractSubjectId;
    }

    public void setContractSubjectId(Integer contractSubjectId) {
        this.contractSubjectId = contractSubjectId;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getFeeSubjectText() {
        return feeSubjectText;
    }

    public void setFeeSubjectText(String feeSubjectText) {
        this.feeSubjectText = feeSubjectText;
    }

    public String getPayObjectText() {
        return payObjectText;
    }

    public void setPayObjectText(String payObjectText) {
        this.payObjectText = payObjectText;
    }
    public String getComputeModeText() {
        return computeModeText;
    }

    public void setComputeModeText(String computeModeText) {
        this.computeModeText = computeModeText;
    }

    public String getContractSubjectName() {
        return contractSubjectName;
    }

    public void setContractSubjectName(String contractSubjectName) {
        this.contractSubjectName = contractSubjectName;
    }

    public BigDecimal getNoTaxAmountMoney() {
        return noTaxAmountMoney;
    }

    public void setNoTaxAmountMoney(BigDecimal noTaxAmountMoney) {
        this.noTaxAmountMoney = noTaxAmountMoney;
    }

}
